[pkg-php-pear] Bug#1065075: bullseye-pu: package symfony/4.4.19+dfsg-2+deb11u5

David Prévot taffit at debian.org
Thu Feb 29 13:50:34 GMT 2024


Package: release.debian.org
Severity: normal
Tags: bullseye
X-Debbugs-Cc: symfony at packages.debian.org, team at security.debian.org
Control: affects -1 + src:symfony
User: release.debian.org at packages.debian.org
Usertags: pu

[3/6 for bullseye]

This is a follow up from composer/DSA-5632-1, similar to #1065059 in
bookworm.

In order to fix a Debian-specific issue related to CVE-2024-24821, we
agreed with the security team to push related dependencies via the next
point release. It also adds an upstream patch in order to fix the
testsuite, already referenced via #1061033 in Debian.

The only change (besides changelog entry) in the binary packages is of
the following kind (thanks to diffoscope), for example for
php-symfony-cache.

│ │ ├── ./usr/share/php/Symfony/Component/Cache/autoload.php
│ │ │ @@ -1,14 +1,13 @@
│ │ │  <?php
│ │ │ -// require:
│ │ │ -require_once 'Psr/Cache/autoload.php';
│ │ │ -require_once 'Psr/Log/autoload.php';
│ │ │ -require_once 'Symfony/Contracts/Cache/autoload.php';
│ │ │ -require_once 'Symfony/Contracts/Service/autoload.php';
│ │ │ -require_once 'Symfony/Component/VarExporter/autoload.php';
│ │ │ +require_once __DIR__ . '/../../../Psr/Cache/autoload.php';
│ │ │ +require_once __DIR__ . '/../../../Psr/Log/autoload.php';
│ │ │ +require_once __DIR__ . '/../VarExporter/autoload.php';
│ │ │ +require_once __DIR__ . '/../../Contracts/Cache/autoload.php';
│ │ │ +require_once __DIR__ . '/../../Contracts/Service/autoload.php';
│ │ │  
│ │ │  // @codingStandardsIgnoreFile

The goal is to ensure related dependencies are loaded from the system
path.

The attached debdiff is a lot bigger, since this source package builds
a hundred binary packages, and that d/rules has been adapted to keep the
testsuite at buildtime effective.

[ Checklist ]
  [x] *all* changes are documented in the d/changelog
  [x] I reviewed all changes and I approve them
  [x] attach debdiff against the package in (old)stable
  [x] the issue is verified as fixed in unstable

TIA for considering.

Cheers,

taffit
-------------- next part --------------
diff -Nru symfony-4.4.19+dfsg/debian/changelog symfony-4.4.19+dfsg/debian/changelog
--- symfony-4.4.19+dfsg/debian/changelog	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/changelog	2024-02-18 10:59:51.000000000 +0100
@@ -1,3 +1,10 @@
+symfony (4.4.19+dfsg-2+deb11u5) bullseye; urgency=medium
+
+  * make sure that the submitted year is an accepted choice (Closes: #1061033)
+  * Force system dependencies loading
+
+ -- David Prévot <taffit at debian.org>  Sun, 18 Feb 2024 10:59:51 +0100
+
 symfony (4.4.19+dfsg-2+deb11u4) bullseye; urgency=medium
 
   * [Mime] regenerate test certificates (Closes: #1034854)
diff -Nru symfony-4.4.19+dfsg/debian/clean symfony-4.4.19+dfsg/debian/clean
--- symfony-4.4.19+dfsg/debian/clean	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/clean	2024-02-18 10:59:51.000000000 +0100
@@ -1,5 +1,6 @@
 .phpunit.result.cache
 CHANGELOG
+build/
 debian/autoloaders/
 debian/packages_to_build/
 vendor/
diff -Nru symfony-4.4.19+dfsg/debian/patches/make-sure-that-the-submitted-year-is-an-accepted-choice.patch symfony-4.4.19+dfsg/debian/patches/make-sure-that-the-submitted-year-is-an-accepted-choice.patch
--- symfony-4.4.19+dfsg/debian/patches/make-sure-that-the-submitted-year-is-an-accepted-choice.patch	1970-01-01 01:00:00.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/patches/make-sure-that-the-submitted-year-is-an-accepted-choice.patch	2024-02-18 10:59:51.000000000 +0100
@@ -0,0 +1,35 @@
+From: Christian Flothmann <christian.flothmann at qossmic.com>
+Date: Tue, 2 Jan 2024 08:56:56 +0100
+Subject: make sure that the submitted year is an accepted choice
+
+Origin: upstream, https://github.com/symfony/symfony/commit/64f675ced4c60a67f564608fb598dc27ea3de9f6
+Bug-Debian: https://bugs.debian.org/1061033
+---
+ .../Component/Form/Tests/Extension/Core/Type/DateTimeTypeTest.php        | 1 +
+ src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTypeTest.php    | 1 +
+ 2 files changed, 2 insertions(+)
+
+diff --git a/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTimeTypeTest.php b/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTimeTypeTest.php
+index 506ec11..3016069 100644
+--- a/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTimeTypeTest.php
++++ b/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTimeTypeTest.php
+@@ -701,6 +701,7 @@ class DateTimeTypeTest extends BaseTypeTest
+         $form = $this->factory->create(static::TESTED_TYPE, null, [
+             'widget' => $widget,
+             'empty_data' => $emptyData,
++            'years' => range(2018, (int) date('Y')),
+         ]);
+         $form->submit(null);
+ 
+diff --git a/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTypeTest.php b/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTypeTest.php
+index 5891cc0..893fac1 100644
+--- a/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTypeTest.php
++++ b/src/Symfony/Component/Form/Tests/Extension/Core/Type/DateTypeTest.php
+@@ -1021,6 +1021,7 @@ class DateTypeTest extends BaseTypeTest
+         $form = $this->factory->create(static::TESTED_TYPE, null, [
+             'widget' => $widget,
+             'empty_data' => $emptyData,
++            'years' => range(2018, (int) date('Y')),
+         ]);
+         $form->submit(null);
+ 
diff -Nru symfony-4.4.19+dfsg/debian/patches/series symfony-4.4.19+dfsg/debian/patches/series
--- symfony-4.4.19+dfsg/debian/patches/series	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/patches/series	2024-02-18 10:59:51.000000000 +0100
@@ -24,3 +24,4 @@
 Security-Http-Remove-CSRF-tokens-from-storage-on-successf.patch
 Mime-regenerate-test-certificates.patch
 TwigBridge-Ensure-CodeExtension-s-filters-properly-escape.patch
+make-sure-that-the-submitted-year-is-an-accepted-choice.patch
diff -Nru symfony-4.4.19+dfsg/debian/patches/VarDumper-Adapt-to-homemade-autoload.patch symfony-4.4.19+dfsg/debian/patches/VarDumper-Adapt-to-homemade-autoload.patch
--- symfony-4.4.19+dfsg/debian/patches/VarDumper-Adapt-to-homemade-autoload.patch	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/patches/VarDumper-Adapt-to-homemade-autoload.patch	2024-02-18 10:59:51.000000000 +0100
@@ -4,11 +4,11 @@
 
 Forwarded: no
 ---
- src/Symfony/Component/VarDumper/Resources/bin/var-dump-server | 8 ++++----
- 1 file changed, 4 insertions(+), 4 deletions(-)
+ src/Symfony/Component/VarDumper/Resources/bin/var-dump-server | 6 ++----
+ 1 file changed, 2 insertions(+), 4 deletions(-)
 
 diff --git a/src/Symfony/Component/VarDumper/Resources/bin/var-dump-server b/src/Symfony/Component/VarDumper/Resources/bin/var-dump-server
-index 98c813a..5905c4a 100755
+index 98c813a..1223876 100755
 --- a/src/Symfony/Component/VarDumper/Resources/bin/var-dump-server
 +++ b/src/Symfony/Component/VarDumper/Resources/bin/var-dump-server
 @@ -1,4 +1,4 @@
@@ -17,17 +17,14 @@
  <?php
  
  /*
-@@ -31,10 +31,10 @@ function includeIfExists(string $file): bool
+@@ -31,9 +31,7 @@ function includeIfExists(string $file): bool
  }
  
  if (
 -    !includeIfExists(__DIR__ . '/../../../../autoload.php') &&
 -    !includeIfExists(__DIR__ . '/../../vendor/autoload.php') &&
 -    !includeIfExists(__DIR__ . '/../../../../../../vendor/autoload.php')
-+    stream_resolve_include_path('Symfony/Component/VarDumper/autoload.php')
++    !includeIfExists(__DIR__ . '/../share/php/Symfony/Component/VarDumper/autoload.php')
  ) {
-+    include_once 'Symfony/Component/VarDumper/autoload.php';
-+} else {
      fwrite(STDERR, 'Install dependencies using Composer.'.PHP_EOL);
      exit(1);
- }
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-amazon-mailer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-amazon-mailer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-amazon-mailer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-amazon-mailer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Component/Mailer/autoload.php';
+require_once __DIR__ . '/../../autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-asset.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-asset.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-asset.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-asset.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,8 +1,6 @@
 <?php
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/HttpFoundation/autoload.php')){
-    include_once 'Symfony/Component/HttpFoundation/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../HttpFoundation/autoload.php')) { include_once __DIR__ . '/../HttpFoundation/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-browser-kit.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-browser-kit.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-browser-kit.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-browser-kit.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,11 +1,9 @@
 <?php
 // require:
-require_once 'Symfony/Component/DomCrawler/autoload.php';
+require_once __DIR__ . '/../DomCrawler/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Process/autoload.php')){
-    include_once 'Symfony/Component/Process/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../Process/autoload.php')) { include_once __DIR__ . '/../Process/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-cache.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-cache.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-cache.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-cache.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,10 +1,9 @@
 <?php
-// require:
-require_once 'Psr/Cache/autoload.php';
-require_once 'Psr/Log/autoload.php';
-require_once 'Symfony/Contracts/Cache/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
-require_once 'Symfony/Component/VarExporter/autoload.php';
+require_once __DIR__ . '/../../../Psr/Cache/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
+require_once __DIR__ . '/../VarExporter/autoload.php';
+require_once __DIR__ . '/../../Contracts/Cache/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-config.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-config.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-config.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-config.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,11 +1,9 @@
 <?php
 // require:
-require_once 'Symfony/Component/Filesystem/autoload.php';
+require_once __DIR__ . '/../Filesystem/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../Yaml/autoload.php')) { include_once __DIR__ . '/../Yaml/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-console.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-console.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-console.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-console.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,21 +1,13 @@
 <?php
 // require:
-require_once 'Symfony/Polyfill/Php80/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../../Polyfill/Php80/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/EventDispatcher/autoload.php')){
-    include_once 'Symfony/Component/EventDispatcher/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Lock/autoload.php')){
-    include_once 'Symfony/Component/Lock/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Process/autoload.php')){
-    include_once 'Symfony/Component/Process/autoload.php';
-}
-if (stream_resolve_include_path('Psr/Log/autoload.php')){
-    include_once 'Psr/Log/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../../Psr/Log/autoload.php')) { include_once __DIR__ . '/../../../Psr/Log/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../EventDispatcher/autoload.php')) { include_once __DIR__ . '/../EventDispatcher/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Lock/autoload.php')) { include_once __DIR__ . '/../Lock/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Process/autoload.php')) { include_once __DIR__ . '/../Process/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-debug.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-debug.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-debug.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-debug.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,7 +1,7 @@
 <?php
 // require:
-require_once 'Symfony/Polyfill/Php80/autoload.php';
-require_once 'Psr/Log/autoload.php';
+require_once __DIR__ . '/../../Polyfill/Php80/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-debug-bundle.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-debug-bundle.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-debug-bundle.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-debug-bundle.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,16 +1,12 @@
 <?php
 // require:
-require_once 'Symfony/Component/HttpKernel/autoload.php';
-require_once 'Symfony/Bridge/Twig/autoload.php';
-require_once 'Symfony/Component/VarDumper/autoload.php';
+require_once __DIR__ . '/../../Bridge/Twig/autoload.php';
+require_once __DIR__ . '/../../Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../Component/VarDumper/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
-    include_once 'Symfony/Component/Config/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/DependencyInjection/autoload.php')){
-    include_once 'Symfony/Component/DependencyInjection/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Config/autoload.php')) { include_once __DIR__ . '/../../Component/Config/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/DependencyInjection/autoload.php')) { include_once __DIR__ . '/../../Component/DependencyInjection/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-dependency-injection.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-dependency-injection.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-dependency-injection.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-dependency-injection.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,24 +1,14 @@
 <?php
 // require
-require_once 'Psr/Container/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../../../Psr/Container/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
-    include_once 'Symfony/Component/Config/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Finder/autoload.php')){
-    include_once 'Symfony/Component/Finder/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/ExpressionLanguage/autoload.php')){
-    include_once 'Symfony/Component/ExpressionLanguage/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Bridge/ProxyManager/autoload.php')){
-    include_once 'Symfony/Bridge/ProxyManager/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Bridge/ProxyManager/autoload.php')) { include_once __DIR__ . '/../../Bridge/ProxyManager/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Config/autoload.php')) { include_once __DIR__ . '/../Config/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../ExpressionLanguage/autoload.php')) { include_once __DIR__ . '/../ExpressionLanguage/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Finder/autoload.php')) { include_once __DIR__ . '/../Finder/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Yaml/autoload.php')) { include_once __DIR__ . '/../Yaml/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-doctrine-bridge.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-doctrine-bridge.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-doctrine-bridge.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-doctrine-bridge.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,28 +1,16 @@
 <?php
 // require:
-require_once 'Doctrine/Common/EventManager/autoload.php';
-require_once 'Doctrine/Persistence/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../../../Doctrine/Common/EventManager/autoload.php';
+require_once __DIR__ . '/../../../Doctrine/Persistence/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Form/autoload.php')){
-    include_once 'Symfony/Component/Form/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Validator/autoload.php')){
-    include_once 'Symfony/Component/Validator/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/PropertyInfo/autoload.php')){
-    include_once 'Symfony/Component/PropertyInfo/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/Common/DataFixtures/autoload.php')){
-    include_once 'Doctrine/Common/DataFixtures/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/DBAL/autoload.php')){
-    include_once 'Doctrine/DBAL/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/ORM/autoload.php')){
-    include_once 'Doctrine/ORM/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../../Doctrine/Common/DataFixtures/autoload.php')) { include_once __DIR__ . '/../../../Doctrine/Common/DataFixtures/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../Doctrine/DBAL/autoload.php')) { include_once __DIR__ . '/../../../Doctrine/DBAL/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../Doctrine/ORM/autoload.php')) { include_once __DIR__ . '/../../../Doctrine/ORM/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Form/autoload.php')) { include_once __DIR__ . '/../../Component/Form/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/PropertyInfo/autoload.php')) { include_once __DIR__ . '/../../Component/PropertyInfo/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Validator/autoload.php')) { include_once __DIR__ . '/../../Component/Validator/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-dom-crawler.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-dom-crawler.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-dom-crawler.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-dom-crawler.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,8 +1,6 @@
 <?php
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/CssSelector/autoload.php')){
-    include_once 'Symfony/Component/CssSelector/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../CssSelector/autoload.php')) { include_once __DIR__ . '/../CssSelector/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-error-handler.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-error-handler.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-error-handler.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-error-handler.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,9 +1,9 @@
 <?php
 // require:
-require_once 'Psr/Log/autoload.php';
-require_once 'Symfony/Component/Debug/autoload.php';
-require_once 'Symfony/Polyfill/Php80/autoload.php';
-require_once 'Symfony/Component/VarDumper/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
+require_once __DIR__ . '/../Debug/autoload.php';
+require_once __DIR__ . '/../../Polyfill/Php80/autoload.php';
+require_once __DIR__ . '/../VarDumper/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-event-dispatcher.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-event-dispatcher.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-event-dispatcher.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-event-dispatcher.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,14 +1,10 @@
 <?php
 // require:
-require_once 'Symfony/Contracts/EventDispatcher/autoload.php';
+require_once __DIR__ . '/../../Contracts/EventDispatcher/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/DependencyInjection/autoload.php')){
-    include_once 'Symfony/Component/DependencyInjection/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/HttpKernel/autoload.php')){
-    include_once 'Symfony/Component/HttpKernel/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../DependencyInjection/autoload.php')) { include_once __DIR__ . '/../DependencyInjection/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../HttpKernel/autoload.php')) { include_once __DIR__ . '/../HttpKernel/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-expression-language.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-expression-language.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-expression-language.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-expression-language.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,7 +1,7 @@
 <?php
 // require:
-require_once 'Symfony/Component/Cache/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../Cache/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-form.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-form.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-form.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-form.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,21 +1,15 @@
 <?php
 // require:
-require_once 'Symfony/Component/EventDispatcher/autoload.php';
-require_once 'Symfony/Component/Intl/autoload.php';
-require_once 'Symfony/Component/OptionsResolver/autoload.php';
-require_once 'Symfony/Component/PropertyAccess/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../EventDispatcher/autoload.php';
+require_once __DIR__ . '/../Intl/autoload.php';
+require_once __DIR__ . '/../OptionsResolver/autoload.php';
+require_once __DIR__ . '/../PropertyAccess/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Validator/autoload.php')){
-    include_once 'Symfony/Component/Validator/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Security/Csrf/autoload.php')){
-    include_once 'Symfony/Component/Security/Csrf/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Bridge/Twig/autoload.php')){
-    include_once 'Symfony/Bridge/Twig/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Bridge/Twig/autoload.php')) { include_once __DIR__ . '/../../Bridge/Twig/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Security/Csrf/autoload.php')) { include_once __DIR__ . '/../Security/Csrf/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Validator/autoload.php')) { include_once __DIR__ . '/../Validator/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-framework-bundle.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-framework-bundle.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-framework-bundle.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-framework-bundle.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,37 +1,23 @@
 <?php
 // require:
-require_once 'Symfony/Component/Cache/autoload.php';
-require_once 'Symfony/Component/Config/autoload.php';
-require_once 'Symfony/Component/DependencyInjection/autoload.php';
-require_once 'Symfony/Component/ErrorHandler/autoload.php';
-require_once 'Symfony/Component/Finder/autoload.php';
-require_once 'Symfony/Component/HttpFoundation/autoload.php';
-require_once 'Symfony/Component/HttpKernel/autoload.php';
-require_once 'Symfony/Component/Filesystem/autoload.php';
-require_once 'Symfony/Component/Routing/autoload.php';
+require_once __DIR__ . '/../../Component/Cache/autoload.php';
+require_once __DIR__ . '/../../Component/Config/autoload.php';
+require_once __DIR__ . '/../../Component/DependencyInjection/autoload.php';
+require_once __DIR__ . '/../../Component/ErrorHandler/autoload.php';
+require_once __DIR__ . '/../../Component/Filesystem/autoload.php';
+require_once __DIR__ . '/../../Component/Finder/autoload.php';
+require_once __DIR__ . '/../../Component/HttpFoundation/autoload.php';
+require_once __DIR__ . '/../../Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../Component/Routing/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Console/autoload.php')){
-    include_once 'Symfony/Component/Console/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Form/autoload.php')){
-    include_once 'Symfony/Component/Form/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Serializer/autoload.php')){
-    include_once 'Symfony/Component/Serializer/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Validator/autoload.php')){
-    include_once 'Symfony/Component/Validator/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/PropertyInfo/autoload.php')){
-    include_once 'Symfony/Component/PropertyInfo/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/WebLink/autoload.php')){
-    include_once 'Symfony/Component/WebLink/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Console/autoload.php')) { include_once __DIR__ . '/../../Component/Console/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Form/autoload.php')) { include_once __DIR__ . '/../../Component/Form/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/PropertyInfo/autoload.php')) { include_once __DIR__ . '/../../Component/PropertyInfo/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Serializer/autoload.php')) { include_once __DIR__ . '/../../Component/Serializer/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Validator/autoload.php')) { include_once __DIR__ . '/../../Component/Validator/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/WebLink/autoload.php')) { include_once __DIR__ . '/../../Component/WebLink/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Yaml/autoload.php')) { include_once __DIR__ . '/../../Component/Yaml/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-google-mailer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-google-mailer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-google-mailer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-google-mailer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,5 @@
 <?php
-// require:
-require_once 'Symfony/Component/Mailer/autoload.php';
+require_once __DIR__ . '/../../autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-http-client.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-http-client.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-http-client.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-http-client.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,8 +1,7 @@
 <?php
-// require:
-require_once 'Psr/Log/autoload.php';
-require_once 'Symfony/Contracts/HttpClient/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
+require_once __DIR__ . '/../../Contracts/HttpClient/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-http-foundation.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-http-foundation.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-http-foundation.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-http-foundation.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,7 +1,7 @@
 <?php
 // require:
-require_once 'Symfony/Component/Mime/autoload.php';
-require_once 'Symfony/Polyfill/Php80/autoload.php';
+require_once __DIR__ . '/../Mime/autoload.php';
+require_once __DIR__ . '/../../Polyfill/Php80/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-http-kernel.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-http-kernel.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-http-kernel.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-http-kernel.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,28 +1,18 @@
 <?php
 // require:
-require_once 'Symfony/Component/ErrorHandler/autoload.php';
-require_once 'Symfony/Component/EventDispatcher/autoload.php';
-require_once 'Symfony/Contracts/HttpClient/autoload.php';
-require_once 'Symfony/Component/HttpFoundation/autoload.php';
-require_once 'Symfony/Polyfill/Php80/autoload.php';
-require_once 'Psr/Log/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
+require_once __DIR__ . '/../ErrorHandler/autoload.php';
+require_once __DIR__ . '/../EventDispatcher/autoload.php';
+require_once __DIR__ . '/../HttpClient/autoload.php';
+require_once __DIR__ . '/../HttpFoundation/autoload.php';
+require_once __DIR__ . '/../../Polyfill/Php80/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/BrowserKit/autoload.php')){
-    include_once 'Symfony/Component/BrowserKit/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
-    include_once 'Symfony/Component/Config/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Console/autoload.php')){
-    include_once 'Symfony/Component/Console/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/DependencyInjection/autoload.php')){
-    include_once 'Symfony/Component/DependencyInjection/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/VarDumper/autoload.php')){
-    include_once 'Symfony/Component/VarDumper/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../BrowserKit/autoload.php')) { include_once __DIR__ . '/../BrowserKit/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Config/autoload.php')) { include_once __DIR__ . '/../Config/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Console/autoload.php')) { include_once __DIR__ . '/../Console/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../DependencyInjection/autoload.php')) { include_once __DIR__ . '/../DependencyInjection/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../VarDumper/autoload.php')) { include_once __DIR__ . '/../VarDumper/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-ldap.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-ldap.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-ldap.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-ldap.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Component/OptionsResolver/autoload.php';
+require_once __DIR__ . '/../OptionsResolver/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-lock.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-lock.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-lock.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-lock.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Psr/Log/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-mailchimp-mailer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-mailchimp-mailer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-mailchimp-mailer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-mailchimp-mailer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Component/Mailer/autoload.php';
+require_once __DIR__ . '/../../autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-mailer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-mailer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-mailer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-mailer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,10 +1,10 @@
 <?php
 // require:
-require_once 'Egulias/EmailValidator/autoload.php';
-require_once 'Psr/Log/autoload.php';
-require_once 'Symfony/Component/EventDispatcher/autoload.php';
-require_once 'Symfony/Component/Mime/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../../../Egulias/EmailValidator/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
+require_once __DIR__ . '/../EventDispatcher/autoload.php';
+require_once __DIR__ . '/../Mime/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-mailgun-mailer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-mailgun-mailer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-mailgun-mailer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-mailgun-mailer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Component/Mailer/autoload.php';
+require_once __DIR__ . '/../../autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-messenger.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-messenger.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-messenger.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-messenger.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,7 +1,7 @@
 <?php
 // require:
-require_once 'Psr/Log/autoload.php';
-require_once 'Symfony/Polyfill/Php80/autoload.php';
+require_once __DIR__ . '/../../../Psr/Log/autoload.php';
+require_once __DIR__ . '/../../Polyfill/Php80/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-monolog-bridge.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-monolog-bridge.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-monolog-bridge.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-monolog-bridge.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,19 +1,13 @@
 <?php
 // require:
-require_once 'Monolog/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
-require_once 'Symfony/Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../../Monolog/autoload.php';
+require_once __DIR__ . '/../../Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/HttpKernel/autoload.php')){
-    include_once 'Symfony/Component/HttpKernel/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Console/autoload.php')){
-    include_once 'Symfony/Component/Console/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/VarDumper/autoload.php')){
-    include_once 'Symfony/Component/VarDumper/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Console/autoload.php')) { include_once __DIR__ . '/../../Component/Console/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/HttpKernel/autoload.php')) { include_once __DIR__ . '/../../Component/HttpKernel/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/VarDumper/autoload.php')) { include_once __DIR__ . '/../../Component/VarDumper/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-phpunit-bridge.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-phpunit-bridge.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-phpunit-bridge.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-phpunit-bridge.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,10 +1,8 @@
 <?php
-require_once 'PHPUnit/Autoload.php';
+require_once __DIR__ . '/../../../PHPUnit/Autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/ErrorHandler/autoload.php')){
-    include_once 'Symfony/Component/ErrorHandler/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Component/ErrorHandler/autoload.php')) { include_once __DIR__ . '/../../Component/ErrorHandler/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
@@ -27,5 +25,5 @@
 );
 // @codeCoverageIgnoreEnd
 
-require_once 'Symfony/Bridge/PhpUnit/bootstrap.php';
-require_once 'Symfony/Bridge/PhpUnit/SymfonyTestsListener.php';
+require_once __DIR__.'/SymfonyTestsListener.php';
+require_once __DIR__.'/bootstrap.php';
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-postmark-mailer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-postmark-mailer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-postmark-mailer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-postmark-mailer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Component/Mailer/autoload.php';
+require_once __DIR__ . '/../../autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-property-access.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-property-access.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-property-access.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-property-access.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,9 @@
 <?php
 // require:
-require_once 'Symfony/Component/Inflector/autoload.php';
+require_once __DIR__ . '/../Inflector/autoload.php';
+
+// Suggest
+if (stream_resolve_include_path(__DIR__ . '/../Cache/autoload.php')) { include_once __DIR__ . '/../Cache/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-property-info.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-property-info.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-property-info.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-property-info.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,20 +1,12 @@
 <?php
 // require:
-require_once 'Symfony/Component/Inflector/autoload.php';
+require_once __DIR__ . '/../Inflector/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Cache/autoload.php')){
-    include_once 'Symfony/Component/Cache/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Bridge/Doctrine/autoload.php')){
-    include_once 'Symfony/Bridge/Doctrine/autoload.php';
-}
-if (stream_resolve_include_path('phpDocumentor/Reflection/DocBlock/autoload.php')){
-    include_once 'phpDocumentor/Reflection/DocBlock/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Serializer/autoload.php')){
-    include_once 'Symfony/Component/Serializer/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Bridge/Doctrine/autoload.php')) { include_once __DIR__ . '/../../Bridge/Doctrine/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Cache/autoload.php')) { include_once __DIR__ . '/../Cache/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Serializer/autoload.php')) { include_once __DIR__ . '/../Serializer/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../phpDocumentor/Reflection/DocBlock/autoload.php')) { include_once __DIR__ . '/../../../phpDocumentor/Reflection/DocBlock/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-proxy-manager-bridge.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-proxy-manager-bridge.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-proxy-manager-bridge.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-proxy-manager-bridge.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,9 +1,8 @@
 <?php
 // require:
-require_once 'Symfony/Component/DependencyInjection/autoload.php';
-require_once 'ProxyManager/autoload.php';
+require_once __DIR__ . '/../../../ProxyManager/autoload.php';
+require_once __DIR__ . '/../../Component/DependencyInjection/autoload.php';
 
-// @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
 // this is an autogenerated file - do not edit
 spl_autoload_register(
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-routing.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-routing.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-routing.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-routing.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,20 +1,10 @@
 <?php
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/HttpFoundation/autoload.php')){
-    include_once 'Symfony/Component/HttpFoundation/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
-    include_once 'Symfony/Component/Config/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/ExpressionLanguage/autoload.php')){
-    include_once 'Symfony/Component/ExpressionLanguage/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/Common/Annotations/autoload.php')){
-    include_once 'Doctrine/Common/Annotations/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../Annotations/autoload.php')) { include_once __DIR__ . '/../Annotations/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Config/autoload.php')) { include_once __DIR__ . '/../Config/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../ExpressionLanguage/autoload.php')) { include_once __DIR__ . '/../ExpressionLanguage/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../HttpFoundation/autoload.php')) { include_once __DIR__ . '/../HttpFoundation/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Yaml/autoload.php')) { include_once __DIR__ . '/../Yaml/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-security-bundle.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-security-bundle.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-security-bundle.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-security-bundle.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,12 +1,12 @@
 <?php
 // require:
-require_once 'Symfony/Component/Config/autoload.php';
-require_once 'Symfony/Component/DependencyInjection/autoload.php';
-require_once 'Symfony/Component/HttpKernel/autoload.php';
-require_once 'Symfony/Component/Security/Core/autoload.php';
-require_once 'Symfony/Component/Security/Csrf/autoload.php';
-require_once 'Symfony/Component/Security/Guard/autoload.php';
-require_once 'Symfony/Component/Security/Http/autoload.php';
+require_once __DIR__ . '/../../Component/Config/autoload.php';
+require_once __DIR__ . '/../../Component/DependencyInjection/autoload.php';
+require_once __DIR__ . '/../../Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../Component/Security/Core/autoload.php';
+require_once __DIR__ . '/../../Component/Security/Csrf/autoload.php';
+require_once __DIR__ . '/../../Component/Security/Guard/autoload.php';
+require_once __DIR__ . '/../../Component/Security/Http/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-security-core.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-security-core.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-security-core.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-security-core.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,27 +1,15 @@
 <?php
 // require:
-require_once 'Symfony/Contracts/EventDispatcher/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../../../Contracts/EventDispatcher/autoload.php';
+require_once __DIR__ . '/../../../Contracts/Service/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Psr/Container/autoload.php')){
-    include_once 'Psr/Container/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/EventDispatcher/autoload.php')){
-    include_once 'Symfony/Component/EventDispatcher/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/HttpFoundation/autoload.php')){
-    include_once 'Symfony/Component/HttpFoundation/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Validator/autoload.php')){
-    include_once 'Symfony/Component/Validator/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/ExpressionLanguage/autoload.php')){
-    include_once 'Symfony/Component/ExpressionLanguage/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Ldap/autoload.php')){
-    include_once 'Symfony/Component/Ldap/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../../../Psr/Log/autoload.php')) { include_once __DIR__ . '/../../../../Psr/Log/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../EventDispatcher/autoload.php')) { include_once __DIR__ . '/../../EventDispatcher/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../ExpressionLanguage/autoload.php')) { include_once __DIR__ . '/../../ExpressionLanguage/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../HttpFoundation/autoload.php')) { include_once __DIR__ . '/../../HttpFoundation/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Ldap/autoload.php')) { include_once __DIR__ . '/../../Ldap/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Validator/autoload.php')) { include_once __DIR__ . '/../../Validator/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-security-csrf.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-security-csrf.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-security-csrf.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-security-csrf.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,11 +1,9 @@
 <?php
 // require:
-require_once 'Symfony/Component/Security/Core/autoload.php';
+require_once __DIR__ . '/../Core/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/HttpFoundation/autoload.php')){
-    include_once 'Symfony/Component/HttpFoundation/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../HttpFoundation/autoload.php')) { include_once __DIR__ . '/../../HttpFoundation/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-security-guard.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-security-guard.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-security-guard.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-security-guard.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,7 +1,7 @@
 <?php
 // require:
-require_once 'Symfony/Component/Security/Core/autoload.php';
-require_once 'Symfony/Component/Security/Http/autoload.php';
+require_once __DIR__ . '/../Core/autoload.php';
+require_once __DIR__ . '/../Http/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-security-http.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-security-http.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-security-http.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-security-http.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,17 +1,14 @@
 <?php
 // require:
-require_once 'Symfony/Component/Security/Core/autoload.php';
-require_once 'Symfony/Component/HttpFoundation/autoload.php';
-require_once 'Symfony/Component/HttpKernel/autoload.php';
-require_once 'Symfony/Component/PropertyAccess/autoload.php';
+// Require
+require_once __DIR__ . '/../../HttpFoundation/autoload.php';
+require_once __DIR__ . '/../../HttpKernel/autoload.php';
+require_once __DIR__ . '/../../PropertyAccess/autoload.php';
+require_once __DIR__ . '/../Core/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Security/Csrf/autoload.php')){
-    include_once 'Symfony/Component/Security/Csrf/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Routing/autoload.php')){
-    include_once 'Symfony/Component/Routing/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Routing/autoload.php')) { include_once __DIR__ . '/../../Routing/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Csrf/autoload.php')) { include_once __DIR__ . '/../Csrf/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-sendgrid-mailer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-sendgrid-mailer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-sendgrid-mailer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-sendgrid-mailer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Component/Mailer/autoload.php';
+require_once __DIR__ . '/../../autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-serializer.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-serializer.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-serializer.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-serializer.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,29 +1,13 @@
 <?php
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Cache/autoload.php')){
-    include_once 'Symfony/Component/Cache/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/PropertyInfo/autoload.php')){
-    include_once 'Symfony/Component/PropertyInfo/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
-    include_once 'Symfony/Component/Config/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/PropertyAccess/autoload.php')){
-    include_once 'Symfony/Component/PropertyAccess/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/HttpFoundation/autoload.php')){
-    include_once 'Symfony/Component/HttpFoundation/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/Common/Annotations/autoload.php')){
-    include_once 'Doctrine/Common/Annotations/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/Common/Cache/autoload.php')){
-    include_once 'Doctrine/Common/Cache/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../Cache/autoload.php')) { include_once __DIR__ . '/../Cache/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Config/autoload.php')) { include_once __DIR__ . '/../Config/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../HttpFoundation/autoload.php')) { include_once __DIR__ . '/../HttpFoundation/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../PropertyAccess/autoload.php')) { include_once __DIR__ . '/../PropertyAccess/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../PropertyInfo/autoload.php')) { include_once __DIR__ . '/../PropertyInfo/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Yaml/autoload.php')) { include_once __DIR__ . '/../Yaml/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../Doctrine/Common/Annotations/autoload.php')) { include_once __DIR__ . '/../../../Doctrine/Common/Annotations/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../Doctrine/Common/Cache/autoload.php')) { include_once __DIR__ . '/../../../Doctrine/Common/Cache/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-stopwatch.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-stopwatch.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-stopwatch.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-stopwatch.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Contracts/Service/autoload.php';
+require_once __DIR__ . '/../../Contracts/Service/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-templating.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-templating.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-templating.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-templating.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,8 +1,6 @@
 <?php
 // suggest:
-if (stream_resolve_include_path('Psr/Log/autoload.php')){
-    include_once 'Psr/Log/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../../Psr/Log/autoload.php')) { include_once __DIR__ . '/../../../Psr/Log/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-translation.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-translation.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-translation.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-translation.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,17 +1,11 @@
 <?php
 // require:
-require_once 'Symfony/Contracts/Translation/autoload.php';
+require_once __DIR__ . '/../../Contracts/Translation/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
-    include_once 'Symfony/Component/Config/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
-if (stream_resolve_include_path('Psr/Log/autoload.php')){
-    include_once 'Psr/Log/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../Config/autoload.php')) { include_once __DIR__ . '/../Config/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Yaml/autoload.php')) { include_once __DIR__ . '/../Yaml/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../Psr/Log/autoload.php')) { include_once __DIR__ . '/../../../Psr/Log/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-twig-bridge.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-twig-bridge.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-twig-bridge.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-twig-bridge.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,54 +1,24 @@
 <?php
 // require:
-require_once 'Symfony/Contracts/Translation/autoload.php';
-require_once 'Twig/autoload.php';
+require_once __DIR__ . '/../../Contracts/Translation/autoload.php';
+require_once __DIR__ . '/../../../Twig/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Finder/autoload.php')){
-    include_once 'Symfony/Component/Finder/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Asset/autoload.php')){
-    include_once 'Symfony/Component/Asset/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Form/autoload.php')){
-    include_once 'Symfony/Component/Form/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/HttpKernel/autoload.php')){
-    include_once 'Symfony/Component/HttpKernel/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Routing/autoload.php')){
-    include_once 'Symfony/Component/Routing/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Templating/autoload.php')){
-    include_once 'Symfony/Component/Templating/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Translation/autoload.php')){
-    include_once 'Symfony/Component/Translation/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Security/Core/autoload.php')){
-    include_once 'Symfony/Component/Security/Core/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Security/Csrf/autoload.php')){
-    include_once 'Symfony/Component/Security/Csrf/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Security/Http/autoload.php')){
-    include_once 'Symfony/Component/Security/Http/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Stopwatch/autoload.php')){
-    include_once 'Symfony/Component/Stopwatch/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/VarDumper/autoload.php')){
-    include_once 'Symfony/Component/VarDumper/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/ExpressionLanguage/autoload.php')){
-    include_once 'Symfony/Component/ExpressionLanguage/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/WebLink/autoload.php')){
-    include_once 'Symfony/Component/WebLink/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Asset/autoload.php')) { include_once __DIR__ . '/../../Component/Asset/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/ExpressionLanguage/autoload.php')) { include_once __DIR__ . '/../../Component/ExpressionLanguage/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Finder/autoload.php')) { include_once __DIR__ . '/../../Component/Finder/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Form/autoload.php')) { include_once __DIR__ . '/../../Component/Form/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/HttpKernel/autoload.php')) { include_once __DIR__ . '/../../Component/HttpKernel/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Routing/autoload.php')) { include_once __DIR__ . '/../../Component/Routing/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Security/Core/autoload.php')) { include_once __DIR__ . '/../../Component/Security/Core/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Security/Csrf/autoload.php')) { include_once __DIR__ . '/../../Component/Security/Csrf/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Security/Http/autoload.php')) { include_once __DIR__ . '/../../Component/Security/Http/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Stopwatch/autoload.php')) { include_once __DIR__ . '/../../Component/Stopwatch/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Templating/autoload.php')) { include_once __DIR__ . '/../../Component/Templating/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Translation/autoload.php')) { include_once __DIR__ . '/../../Component/Translation/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/VarDumper/autoload.php')) { include_once __DIR__ . '/../../Component/VarDumper/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/WebLink/autoload.php')) { include_once __DIR__ . '/../../Component/WebLink/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../Component/Yaml/autoload.php')) { include_once __DIR__ . '/../../Component/Yaml/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-twig-bundle.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-twig-bundle.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-twig-bundle.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-twig-bundle.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,9 +1,8 @@
 <?php
-// require:
-require_once 'Symfony/Bridge/Twig/autoload.php';
-require_once 'Symfony/Component/HttpFoundation/autoload.php';
-require_once 'Symfony/Component/HttpKernel/autoload.php';
-require_once 'Twig/autoload.php';
+require_once __DIR__ . '/../../Bridge/Twig/autoload.php';
+require_once __DIR__ . '/../../Component/HttpFoundation/autoload.php';
+require_once __DIR__ . '/../../Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../../Twig/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-validator.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-validator.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-validator.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-validator.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,44 +1,20 @@
 <?php
 // require:
-require_once 'Symfony/Contracts/Translation/autoload.php';
+require_once __DIR__ . '/../../Contracts/Translation/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Cache/autoload.php')){
-    include_once 'Symfony/Component/Cache/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/Common/Annotations/autoload.php')){
-    include_once 'Doctrine/Common/Annotations/autoload.php';
-}
-if (stream_resolve_include_path('Doctrine/Common/Cache/autoload.php')){
-    include_once 'Doctrine/Common/Cache/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/HttpFoundation/autoload.php')){
-    include_once 'Symfony/Component/HttpFoundation/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Intl/autoload.php')){
-    include_once 'Symfony/Component/Intl/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Translation/autoload.php')){
-    include_once 'Symfony/Component/Translation/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
-    include_once 'Symfony/Component/Yaml/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
-    include_once 'Symfony/Component/Config/autoload.php';
-}
-if (stream_resolve_include_path('Egulias/EmailValidator/autoload.php')){
-    include_once 'Egulias/EmailValidator/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/PropertyAccess/autoload.php')){
-    include_once 'Symfony/Component/PropertyAccess/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/PropertyInfo/autoload.php')){
-    include_once 'Symfony/Component/PropertyInfo/autoload.php';
-}
-if (stream_resolve_include_path('Symfony/Component/ExpressionLanguage/autoload.php')){
-    include_once 'Symfony/Component/ExpressionLanguage/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../../../Doctrine/Common/Annotations/autoload.php')) { include_once __DIR__ . '/../../../Doctrine/Common/Annotations/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../Doctrine/Common/Cache/autoload.php')) { include_once __DIR__ . '/../../../Doctrine/Common/Cache/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../../../Egulias/EmailValidator/autoload.php')) { include_once __DIR__ . '/../../../Egulias/EmailValidator/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Cache/autoload.php')) { include_once __DIR__ . '/../Cache/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Config/autoload.php')) { include_once __DIR__ . '/../Config/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../ExpressionLanguage/autoload.php')) { include_once __DIR__ . '/../ExpressionLanguage/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../HttpFoundation/autoload.php')) { include_once __DIR__ . '/../HttpFoundation/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Intl/autoload.php')) { include_once __DIR__ . '/../Intl/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../PropertyAccess/autoload.php')) { include_once __DIR__ . '/../PropertyAccess/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../PropertyInfo/autoload.php')) { include_once __DIR__ . '/../PropertyInfo/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Translation/autoload.php')) { include_once __DIR__ . '/../Translation/autoload.php'; }
+if (stream_resolve_include_path(__DIR__ . '/../Yaml/autoload.php')) { include_once __DIR__ . '/../Yaml/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-var-dumper.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-var-dumper.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-var-dumper.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-var-dumper.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,10 +1,8 @@
 <?php
-require_once 'Symfony/Polyfill/Php80/autoload.php';
+require_once __DIR__ . '/../../Polyfill/Php80/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Console/autoload.php')){
-    include_once 'Symfony/Component/Console/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../Console/autoload.php')) { include_once __DIR__ . '/../Console/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
@@ -27,4 +25,4 @@
 );
 // @codeCoverageIgnoreEnd
 
-require_once 'Symfony/Component/VarDumper/Resources/functions/dump.php';
+require_once __DIR__.'/Resources/functions/dump.php';
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-web-link.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-web-link.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-web-link.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-web-link.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,11 +1,9 @@
 <?php
 // require:
-require_once 'Psr/Link/autoload.php';
+require_once __DIR__ . '/../../../Psr/Link/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/HttpKernel/autoload.php')){
-    include_once 'Symfony/Component/HttpKernel/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../HttpKernel/autoload.php')) { include_once __DIR__ . '/../HttpKernel/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-web-profiler-bundle.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-web-profiler-bundle.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-web-profiler-bundle.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-web-profiler-bundle.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,11 +1,11 @@
 <?php
 // require:
-require_once 'Symfony/Component/Config/autoload.php';
-require_once 'Symfony/Bundle/FrameworkBundle/autoload.php';
-require_once 'Symfony/Component/HttpKernel/autoload.php';
-require_once 'Symfony/Component/Routing/autoload.php';
-require_once 'Symfony/Bundle/TwigBundle/autoload.php';
-require_once 'Twig/autoload.php';
+require_once __DIR__ . '/../FrameworkBundle/autoload.php';
+require_once __DIR__ . '/../TwigBundle/autoload.php';
+require_once __DIR__ . '/../../Component/Config/autoload.php';
+require_once __DIR__ . '/../../Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../Component/Routing/autoload.php';
+require_once __DIR__ . '/../../../Twig/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-web-server-bundle.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-web-server-bundle.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-web-server-bundle.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-web-server-bundle.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,17 +1,17 @@
 <?php
 // require:
-require_once 'Symfony/Component/Config/autoload.php'; // Suggested by HttpKernel
-require_once 'Symfony/Component/Console/autoload.php';
-// require_once 'Symfony/Component/DependencyInjection/autoload.php'; Required by EventDispatcher, required by HttpKernel
-require_once 'Symfony/Component/HttpKernel/autoload.php';
-require_once 'Symfony/Component/Process/autoload.php';
+require_once __DIR__ . '/../../Component/Config/autoload.php'; // Suggested by HttpKernel
+require_once __DIR__ . '/../../Component/Console/autoload.php';
+// require_once __DIR__ . '/../../Component/DependencyInjection/autoload.php'; Required by EventDispatcher, required by HttpKernel
+require_once __DIR__ . '/../../Component/HttpKernel/autoload.php';
+require_once __DIR__ . '/../../Component/Process/autoload.php';
 
 // suggest:
-if (stream_resolve_include_path('Symfony/Bridge/Monolog/autoload.php')){
-    include_once 'Symfony/Bridge/Monolog/autoload.php';
+if (stream_resolve_include_path(__DIR__ . '/../Monolog/autoload.php')){
+    include_once __DIR__ . '/../Monolog/autoload.php';
 }
-if (stream_resolve_include_path('Symfony/Component/ExpressionLanguage/autoload.php')){
-    include_once 'Symfony/Component/ExpressionLanguage/autoload.php';
+if (stream_resolve_include_path(__DIR__ . '/../../Component/ExpressionLanguage/autoload.php')){
+    include_once __DIR__ . '/../../Component/ExpressionLanguage/autoload.php';
 }
 
 // @codingStandardsIgnoreFile
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-workflow.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-workflow.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-workflow.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-workflow.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 // require:
-require_once 'Symfony/Component/PropertyAccess/autoload.php';
+require_once __DIR__ . '/../PropertyAccess/autoload.php';
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-yaml.autoload.php.tpl symfony-4.4.19+dfsg/debian/php-symfony-yaml.autoload.php.tpl
--- symfony-4.4.19+dfsg/debian/php-symfony-yaml.autoload.php.tpl	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-yaml.autoload.php.tpl	2024-02-18 10:59:51.000000000 +0100
@@ -1,8 +1,6 @@
 <?php
 // suggest:
-if (stream_resolve_include_path('Symfony/Component/Console/autoload.php')){
-    include_once 'Symfony/Component/Console/autoload.php';
-}
+if (stream_resolve_include_path(__DIR__ . '/../Console/autoload.php')) { include_once __DIR__ . '/../Console/autoload.php'; }
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
diff -Nru symfony-4.4.19+dfsg/debian/rules symfony-4.4.19+dfsg/debian/rules
--- symfony-4.4.19+dfsg/debian/rules	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/rules	2024-02-18 10:59:51.000000000 +0100
@@ -72,19 +72,38 @@
 
 
 override_dh_auto_test:
-	ln -s ./src/Symfony ./Symfony
-	mkdir --parents vendor
-	cp debian/autoload.php src/Symfony
+	mkdir --parents vendor build
+	cp -r src/Symfony build
+	rm -r build/Symfony/Contracts
+	cp debian/autoload.php build/Symfony
 	phpab	--output vendor/autoload.php \
 		--whitelist '*\\tests\\*' \
 		--tolerant \
 		--template debian/autoload.php.tests.tpl \
 		--blacklist 'symfony\\component\\dependencyinjection\\tests\\fixtures\\container\\projectservicecontainer' \
-		--exclude 'Symfony/Bridge/ProxyManager/Tests/LazyProxy/PhpDumper/Fixtures/proxy-implem.php' \
-		Symfony
+		--exclude 'build/Symfony/Bridge/ProxyManager/Tests/LazyProxy/PhpDumper/Fixtures/proxy-implem.php' \
+		build/Symfony
+	ln -s /usr/share/php/Cache build
+	ln -s /usr/share/php/Doctrine build
+	ln -s /usr/share/php/Egulias build
+	ln -s /usr/share/php/GuzzleHttp build
+	ln -s /usr/share/php/Http build
+	ln -s /usr/share/php/Masterminds build
+	ln -s /usr/share/php/Monolog build
+	ln -s /usr/share/php/Nyholm build
+	ln -s /usr/share/php/phpDocumentor build
+	ln -s /usr/share/php/PHPUnit build
+	ln -s /usr/share/php/Predis build
+	ln -s /usr/share/php/ProxyManager build
+	ln -s /usr/share/php/Psr build
+	ln -s /usr/share/php/Symfony/Contracts build/Symfony
+	ln -s /usr/share/php/Symfony/Component/Security/Acl build/Symfony/Component/Security
+	ln -s /usr/share/php/Symfony/Polyfill build/Symfony
+	ln -s /usr/share/php/Twig build
+	ln -s build/Symfony .
 	# Actual tests suite
-	components=$$(find src/Symfony -mindepth 3 -type f -name phpunit.xml.dist -printf '%h\n') && \
-	 echo "$$components" | parallel --gnu --keep-order '/bin/echo -e "\\nRunning {} tests"; SYMFONY_DEPRECATIONS_HELPER=weak phpunit -v --colors=always --exclude-group network,tty,benchmark,intl-data,functional,composer {} || (/bin/echo -e "\\e[41mKO\\e[0m {}" && $$(exit 1));';
+	components=$$(find build/Symfony -mindepth 3 -type f -name phpunit.xml.dist -printf '%h\n') && \
+	 echo "$$components" | parallel --gnu --keep-order '/bin/echo -e "\\nRunning {} tests"; SYMFONY_DEPRECATIONS_HELPER=weak phpunit --include build -v --colors=always --exclude-group network,tty,benchmark,intl-data,functional,composer {} || (/bin/echo -e "\\e[41mKO\\e[0m {}" && $$(exit 1));';
 
 override_dh_phpcomposer:
 	dh_phpcomposer --package=php-symfony --sourcedirectory=./
-------------- next part --------------
A non-text attachment was scrubbed...
Name: signature.asc
Type: application/pgp-signature
Size: 488 bytes
Desc: not available
URL: <http://alioth-lists.debian.net/pipermail/pkg-php-pear/attachments/20240229/e6be0b3e/attachment-0001.sig>


More information about the pkg-php-pear mailing list
diff -Nru symfony-4.4.19+dfsg/debian/autoload.php symfony-4.4.19+dfsg/debian/autoload.php
--- symfony-4.4.19+dfsg/debian/autoload.php	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/autoload.php	2024-02-18 10:59:51.000000000 +0100
@@ -1,76 +1,76 @@
 <?php
 
 // require_once 'Doctrine/Common/EventManager/autoload.php'; (already required by at least Bridge/Doctrine)
 // require_once 'Doctrine/Common/Persistence/autoload.php'; (already required by at least Bridge/Doctrine)
 // require_once 'Twig/autoload.php'; (already required by Bridge/Twig)
 // require_once 'Psr/Cache/autoload.php'; (already required by Cache)
 // require_once 'Psr/Container/autoload.php'; (already required by DependencyInjection)
 // require_once 'Psr/Link/autoload.php'; (already required by WebLink)
 // require_once 'Psr/Log/autoload.php'; (already required by Debug and more)
 // require_once 'Symfony/Contracts/autoload.php'; (already required by FrameworkBundle and more)
 
-require_once 'Symfony/Component/Mailer/Bridge/Amazon/autoload.php';
-require_once 'Symfony/Component/Asset/autoload.php';  // (already *included* by Bridge/Twig)
-require_once 'Symfony/Component/BrowserKit/autoload.php'; // (already *included* by HttpKernel)
-// require_once 'Symfony/Component/Cache/autoload.php'; (already required by FrameworkBundle and more)
-// require_once 'Symfony/Component/Config/autoload.php'; (already required by FrameworkBundle)
-// require_once 'Symfony/Component/Console/autoload.php'; (already required by WebServerBundle)
-require_once 'Symfony/Component/CssSelector/autoload.php'; // (already *included* by DomCrawler)
-// require_once 'Symfony/Component/DependencyInjection/autoload.php'; (already required by FrameworkBundle and more)
-// require_once 'Symfony/Component/Debug/autoload.php'; (already required by ErrorHandler)
-require_once 'Symfony/Bundle/DebugBundle/autoload.php';
-require_once 'Symfony/Bridge/Doctrine/autoload.php'; // (already *included* by PropertyInfo)
-// require_once 'Symfony/Component/DomCrawler/autoload.php'; (already required by BrowserKit)
-require_once 'Symfony/Component/Dotenv/autoload.php';
-// require_once 'Symfony/Component/ErrorHandler/autoload.php'; (already required by FrameworkBundle)
-// require_once 'Symfony/Component/EventDispatcher/autoload.php'; (already required by Form and more)
-require_once 'Symfony/Component/ExpressionLanguage/autoload.php'; // (already *included* by Security and more)
-// require_once 'Symfony/Component/Filesystem/autoload.php'; (already required by FrameworkBundle and more)
-// require_once 'Symfony/Component/Finder/autoload.php'; (already required by FrameworkBundle and more)
-require_once 'Symfony/Component/Form/autoload.php'; // (already *included* by FrameworkBundle and more)
-// require_once 'Symfony/Bundle/FrameworkBundle/autoload.php'; (already required by WebServerBundle)
-require_once 'Symfony/Component/Mailer/Bridge/Google/autoload.php';
-require_once 'Symfony/Component/HttpClient/autoload.php';
-// require_once 'Symfony/Component/HttpFoundation/autoload.php'; (already required by FrameworkBundle and more)
-// require_once 'Symfony/Component/HttpKernel/autoload.php'; (already required by FrameworkBundle and more)
-// require_once 'Symfony/Component/Inflector/autoload.php'; (already required by PropertyAccess and PropertyInfo)
-// require_once 'Symfony/Component/Intl/autoload.php'; (already required by Form)
-require_once 'Symfony/Component/Ldap/autoload.php'; // (already *included* by Security)
-require_once 'Symfony/Component/Lock/autoload.php'; // (already *included* by Console)
-require_once 'Symfony/Component/Mailer/Bridge/Mailchimp/autoload.php';
-// require_once 'Symfony/Component/Mailer/autoload.php'; (already required by every Mailer Bridge)
-require_once 'Symfony/Component/Mailer/Bridge/Mailgun/autoload.php';
-require_once 'Symfony/Component/Messenger/autoload.php';
-// require_once 'Symfony/Component/Mime/autoload.php'; (already required by BrowserKit and more)
-require_once 'Symfony/Bridge/Monolog/autoload.php'; // (already *included* by WebserverBundle)
-// require_once 'Symfony/Component/OptionsResolver/autoload.php'; (already required by Form)
-require_once 'Symfony/Component/Mailer/Bridge/Postmark/autoload.php';
-require_once 'Symfony/Component/Process/autoload.php'; // (already *included* by FrameworkBundle and more)
-// require_once 'Symfony/Component/PropertyAccess/autoload.php'; (already required by Security and more)
-require_once 'Symfony/Component/PropertyInfo/autoload.php'; // (already *included* by FrameworkBundle and more)
-require_once 'Symfony/Bridge/ProxyManager/autoload.php'; // (already *included* by DependencyInjection)
-// require_once 'Symfony/Component/Routing/autoload.php'; (already required by FrameworkBundle and more)
-// require_once 'Symfony/Component/Security/autoload.php'; (already required by SecurityBundle)
-// require_once 'Symfony/Component/Security/Core/autoload.php'; (already required by Security and more)
-// require_once 'Symfony/Component/Security/Csrf/autoload.php'; (already required by Security and more)
-// require_once 'Symfony/Component/Security/Guard/autoload.php'; (already required by Security and more)
-// require_once 'Symfony/Component/Security/Http/autoload.php'; (already required by Security and more)
-require_once 'Symfony/Bundle/SecurityBundle/autoload.php';
-require_once 'Symfony/Component/Mailer/Bridge/Sendgrid/autoload.php';
-require_once 'Symfony/Component/Serializer/autoload.php'; // (already *included* by FrameworkBundle and more)
-// require_once 'Symfony/Component/Stopwatch/autoload.php'; (already required by EventDispatcher and more)
-require_once 'Symfony/Component/Templating/autoload.php'; // (already *included* by TwigBridge)
-// require_once 'Symfony/Component/Translation/autoload.php'; (already required by Validator)
-// require_once 'Symfony/Bridge/Twig/autoload.php'; (already required by TwigBundle and more)
-require_once 'Symfony/Bundle/TwigBundle/autoload.php';
-require_once 'Symfony/Component/Validator/autoload.php'; // (already *included* by FrameworkBundle and more)
-// require_once 'Symfony/Component/VarDumper/autoload.php'; (already required by DebugBundle)
-// require_once 'Symfony/Component/VarExporter/autoload.php'; (already required by Cache)
-require_once 'Symfony/Component/WebLink/autoload.php'; // (already *included* by FrameworkBundle and TwigBridge)
-require_once 'Symfony/Bundle/WebProfilerBundle/autoload.php';
-require_once 'Symfony/Bundle/WebServerBundle/autoload.php';
-require_once 'Symfony/Component/Workflow/autoload.php';
-require_once 'Symfony/Component/Yaml/autoload.php'; // (already *included* by FrameworkBundle and more)
+require_once __DIR__ . '/Component/Mailer/Bridge/Amazon/autoload.php';
+require_once __DIR__ . '/Component/Asset/autoload.php';  // (already *included* by Bridge/Twig)
+require_once __DIR__ . '/Component/BrowserKit/autoload.php'; // (already *included* by HttpKernel)
+// require_once __DIR__ . '/Component/Cache/autoload.php'; (already required by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/Config/autoload.php'; (already required by FrameworkBundle)
+// require_once __DIR__ . '/Component/Console/autoload.php'; (already required by WebServerBundle)
+require_once __DIR__ . '/Component/CssSelector/autoload.php'; // (already *included* by DomCrawler)
+// require_once __DIR__ . '/Component/DependencyInjection/autoload.php'; (already required by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/Debug/autoload.php'; (already required by ErrorHandler)
+require_once __DIR__ . '/Bundle/DebugBundle/autoload.php';
+require_once __DIR__ . '/Bridge/Doctrine/autoload.php'; // (already *included* by PropertyInfo)
+// require_once __DIR__ . '/Component/DomCrawler/autoload.php'; (already required by BrowserKit)
+require_once __DIR__ . '/Component/Dotenv/autoload.php';
+// require_once __DIR__ . '/Component/ErrorHandler/autoload.php'; (already required by FrameworkBundle)
+// require_once __DIR__ . '/Component/EventDispatcher/autoload.php'; (already required by Form and more)
+require_once __DIR__ . '/Component/ExpressionLanguage/autoload.php'; // (already *included* by Security and more)
+// require_once __DIR__ . '/Component/Filesystem/autoload.php'; (already required by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/Finder/autoload.php'; (already required by FrameworkBundle and more)
+require_once __DIR__ . '/Component/Form/autoload.php'; // (already *included* by FrameworkBundle and more)
+// require_once __DIR__ . '/Bundle/FrameworkBundle/autoload.php'; (already required by WebServerBundle)
+require_once __DIR__ . '/Component/Mailer/Bridge/Google/autoload.php';
+require_once __DIR__ . '/Component/HttpClient/autoload.php';
+// require_once __DIR__ . '/Component/HttpFoundation/autoload.php'; (already required by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/HttpKernel/autoload.php'; (already required by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/Inflector/autoload.php'; (already required by PropertyAccess and PropertyInfo)
+// require_once __DIR__ . '/Component/Intl/autoload.php'; (already required by Form)
+require_once __DIR__ . '/Component/Ldap/autoload.php'; // (already *included* by Security)
+require_once __DIR__ . '/Component/Lock/autoload.php'; // (already *included* by Console)
+require_once __DIR__ . '/Component/Mailer/Bridge/Mailchimp/autoload.php';
+// require_once __DIR__ . '/Component/Mailer/autoload.php'; (already required by every Mailer Bridge)
+require_once __DIR__ . '/Component/Mailer/Bridge/Mailgun/autoload.php';
+require_once __DIR__ . '/Component/Messenger/autoload.php';
+// require_once __DIR__ . '/Component/Mime/autoload.php'; (already required by BrowserKit and more)
+require_once __DIR__ . '/Bridge/Monolog/autoload.php'; // (already *included* by WebserverBundle)
+// require_once __DIR__ . '/Component/OptionsResolver/autoload.php'; (already required by Form)
+require_once __DIR__ . '/Component/Mailer/Bridge/Postmark/autoload.php';
+require_once __DIR__ . '/Component/Process/autoload.php'; // (already *included* by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/PropertyAccess/autoload.php'; (already required by Security and more)
+require_once __DIR__ . '/Component/PropertyInfo/autoload.php'; // (already *included* by FrameworkBundle and more)
+require_once __DIR__ . '/Bridge/ProxyManager/autoload.php'; // (already *included* by DependencyInjection)
+// require_once __DIR__ . '/Component/Routing/autoload.php'; (already required by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/Security/autoload.php'; (already required by SecurityBundle)
+// require_once __DIR__ . '/Component/Security/Core/autoload.php'; (already required by Security and more)
+// require_once __DIR__ . '/Component/Security/Csrf/autoload.php'; (already required by Security and more)
+// require_once __DIR__ . '/Component/Security/Guard/autoload.php'; (already required by Security and more)
+// require_once __DIR__ . '/Component/Security/Http/autoload.php'; (already required by Security and more)
+require_once __DIR__ . '/Bundle/SecurityBundle/autoload.php';
+require_once __DIR__ . '/Component/Mailer/Bridge/Sendgrid/autoload.php';
+require_once __DIR__ . '/Component/Serializer/autoload.php'; // (already *included* by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/Stopwatch/autoload.php'; (already required by EventDispatcher and more)
+require_once __DIR__ . '/Component/Templating/autoload.php'; // (already *included* by TwigBridge)
+// require_once __DIR__ . '/Component/Translation/autoload.php'; (already required by Validator)
+// require_once __DIR__ . '/Bridge/Twig/autoload.php'; (already required by TwigBundle and more)
+require_once __DIR__ . '/Bundle/TwigBundle/autoload.php';
+require_once __DIR__ . '/Component/Validator/autoload.php'; // (already *included* by FrameworkBundle and more)
+// require_once __DIR__ . '/Component/VarDumper/autoload.php'; (already required by DebugBundle)
+// require_once __DIR__ . '/Component/VarExporter/autoload.php'; (already required by Cache)
+require_once __DIR__ . '/Component/WebLink/autoload.php'; // (already *included* by FrameworkBundle and TwigBridge)
+require_once __DIR__ . '/Bundle/WebProfilerBundle/autoload.php';
+require_once __DIR__ . '/Bundle/WebServerBundle/autoload.php';
+require_once __DIR__ . '/Component/Workflow/autoload.php';
+require_once __DIR__ . '/Component/Yaml/autoload.php'; // (already *included* by FrameworkBundle and more)
 
 // @codingStandardsIgnoreFile
 // @codeCoverageIgnoreStart
@@ -1,76 +1,76 @@
 <?php
 
-// require_once 'Doctrine/Common/EventManager/autoload.php'; (already required by at least Bridge/Doctrine)
-// require_once 'Doctrine/Common/Persistence/autoload.php'; (already required by at least Bridge/Doctrine)
-// require_once 'Twig/autoload.php'; (already required by Bridge/Twig)
-// require_once 'Psr/Cache/autoload.php'; (already required by Cache)
-// require_once 'Psr/Container/autoload.php'; (already required by DependencyInjection)
-// require_once 'Psr/Link/autoload.php'; (already required by WebLink)
-// require_once 'Psr/Log/autoload.php'; (already required by Debug and more)
-// require_once 'Symfony/Contracts/autoload.php'; (already required by FrameworkBundle and more)
+// require_once __DIR__ . '/../Doctrine/Common/EventManager/autoload.php'; (already required by at least Bridge/Doctrine)
+// require_once __DIR__ . '/../Doctrine/Common/Persistence/autoload.php'; (already required by at least Bridge/Doctrine)
+// require_once __DIR__ . '/../Twig/autoload.php'; (already required by Bridge/Twig)
+// require_once __DIR__ . '/../Psr/Cache/autoload.php'; (already required by Cache)
+// require_once __DIR__ . '/../Psr/Container/autoload.php'; (already required by DependencyInjection)
+// require_once __DIR__ . '/../Psr/Link/autoload.php'; (already required by WebLink)
+// require_once __DIR__ . '/../Psr/Log/autoload.php'; (already required by Debug and more)
+// require_once __DIR__ . '/Contracts/autoload.php'; (already required by FrameworkBundle and more)
 
diff -Nru symfony-4.4.19+dfsg/debian/php-symfony-security.autoload.php symfony-4.4.19+dfsg/debian/php-symfony-security.autoload.php
--- symfony-4.4.19+dfsg/debian/php-symfony-security.autoload.php	2023-11-11 19:09:20.000000000 +0100
+++ symfony-4.4.19+dfsg/debian/php-symfony-security.autoload.php	2024-02-18 10:59:51.000000000 +0100
@@ -1,6 +1,6 @@
 <?php
 
-// require_once 'Symfony/Component/Security/Core/autoload.php'; (already required by Guard)
-require_once 'Symfony/Component/Security/Csrf/autoload.php';
-require_once 'Symfony/Component/Security/Guard/autoload.php';
-// require_once 'Symfony/Component/Security/Http/autoload.php'; (already required by Guard)
+// require_once __DIR__ . '/Core/autoload.php'; (already required by Guard)
+require_once __DIR__ . '/Csrf/autoload.php';
+require_once __DIR__ . '/Guard/autoload.php';
+// require_once __DIR__ . '/Http/autoload.php'; (already required by Guard)